@@ -24,13 +24,12 @@
 #define KITEMMODELBASE_H
 
 #include "dolphin_export.h"
+#include "kitemviews/kitemrange.h"
+#include "kitemviews/kitemset.h"
 
-#include <kitemviews/kitemrange.h>
-#include <kitemviews/kitemset.h>
-
-#include <QUrl>
 #include <QHash>
 #include <QObject>
+#include <QUrl>
 #include <QVariant>
 
 class QMimeData;
@@ -55,9 +54,9 @@ class DOLPHIN_EXPORT KItemModelBase : public QObject
     Q_OBJECT
 
 public:
-    KItemModelBase(QObject* parent = 0);
-    explicit KItemModelBase(const QByteArray& sortRole, QObject* parent = 0);
-    virtual ~KItemModelBase();
+    explicit KItemModelBase(QObject* parent = nullptr);
+    explicit KItemModelBase(const QByteArray& sortRole, QObject* parent = nullptr);
+    ~KItemModelBase() override;
 
     /** @return The number of items. */
     virtual int count() const = 0;
